Terminal

Compose...
○
Connection Lost
Gestures
Swipe ← / → History up/down
Long press Start selection
Double tap Select word
Pinch Zoom
Modifiers (Ctl, Alt, Sft)
Tap Sticky (one use)
Double tap Lock on/off
Compose Mode (▤)
Type freely, then send to terminal
➤ Send text (or Enter if empty)
Other
TXT Plain text view
Hold × Close tab
Settings
General
Compose Mode
Update Notifications
Security
Require Password Off
Restart server to apply changes
Show URL in CLI
Quick Buttons
Text

Authentication Required
↑
Update Available
→
Run this command to update:
``
Tap anywhere to dismiss